@@ -1,6 +1,6 @@
 package DNS::Oterica::Hub;
 # ABSTRACT: the center of control for a DNS::Oterica system
-$DNS::Oterica::Hub::VERSION = '0.205';
+$DNS::Oterica::Hub::VERSION = '0.206';
 use Moose;
 with 'DNS::Oterica::Role::RecordMaker';
 
@@ -61,7 +61,10 @@ sub soa_rname {
 
 use Module::Pluggable
   search_path => [ qw(DNS::Oterica::NodeFamily) ],
-  require     => 1;
+  require     => 1,
+  $ENV{DNSO_TESTING_PLUGINS}
+    ? (only => [ split /,/, $ENV{DNSO_TESTING_PLUGINS} ])
+    : ();
 
 has fallback_network_name => (is => 'ro', isa => 'Str', default => 'FALLBACK');
 has all_network_name   => (is => 'ro', isa => 'Str', default => 'ALL');
@@ -79,13 +82,13 @@ sub BUILD {
   $self->add_network({
     name => $self->fallback_network_name,
     code => 'FB', # should it be configurable?  eh.
-    subnet => '0.0.0.0/0',
+    subnets => [ '0.0.0.0/0' ],
   });
 
   $self->add_network({
     name => $self->all_network_name,
     code => '',
-    subnet => '0.0.0.0/32',
+    subnets => [ '0.0.0.0/32' ],
   });
 }
 
@@ -163,7 +166,6 @@ sub add_network {
   confess "tried to create $name twice" if $self->_net_registry->{$name};
 
   my $code = $net->code;
-  my $ip   = $net->subnet;
 
   my @errors;
   for my $existing ($self->networks) {
@@ -174,9 +176,13 @@ sub add_network {
 
     next if $existing->name eq $self->all_network_name;
 
-    if ($ip->overlaps($existing->subnet) == $Net::IP::IP_IDENTICAL) {
-      push @errors, sprintf "network '%s' conflicts with network %s (%s)",
-        $ip->ip, $existing->name, $existing->subnet->ip;
+    for my $our ($net->subnets) {
+      for my $their ($existing->subnets) {
+        if ($our->overlaps($their) == $Net::IP::IP_IDENTICAL) {
+          push @errors, sprintf "network '%s' conflicts with network %s (%s)",
+            $our->ip, $existing->name, $their->ip;
+        }
+      }
     }
   }
 
@@ -278,7 +284,7 @@ DNS::Oterica::Hub - the center of control for a DNS::Oterica system
 
 =head1 VERSION
 
-version 0.205
+version 0.206
 
 =head1 OVERVIEW
 
@@ -364,7 +370,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
