@@ -1,6 +1,6 @@
 package DNS::Oterica::Network;
 # ABSTRACT: a network to which results are served
-$DNS::Oterica::Network::VERSION = '0.205';
+$DNS::Oterica::Network::VERSION = '0.206';
 use Moose;
 
 use Net::IP;
@@ -15,6 +15,14 @@ coerce 'DNS::Oterica::Type::Network'
   => from 'Str'
   => via { Net::IP->new($_) || confess( Net::IP::Error() ) };
 
+subtype 'DNS::Oterica::Type::Networks'
+  => as ArrayRef
+  => where { @$_ == grep {; ref $_ and $_->isa('Net::IP') } @$_ };
+
+coerce 'DNS::Oterica::Type::Networks'
+  => from 'ArrayRef'
+  => via { [ map {; Net::IP->new($_) || confess( Net::IP::Error() ) } @$_ ] };
+
 #pod =head1 OVERVIEW
 #pod
 #pod Networks are IP networks to which results are served, and can be used to
@@ -30,33 +38,42 @@ coerce 'DNS::Oterica::Type::Network'
 
 has name => (is => 'ro', isa => 'Str', required => 1);
 
-#pod =attr subnet
+#pod =attr subnets
 #pod
-#pod This is the C<Net::IP> range for the network at this network.
+#pod This is the C<Net::IP> ranges for the network at this network.
 #pod
 #pod =cut
 
-has subnet => (
-  is   => 'ro',
-  isa  => 'DNS::Oterica::Type::Network',
+has subnets => (
+  isa  => 'DNS::Oterica::Type::Networks',
+  traits   => [ 'Array' ],
+  handles  => { subnets => 'elements' },
   required => 1,
   coerce   => 1,
 );
 
 sub _class_prefixes {
-  my ($self, $ip) = @_; # $ip arg for testing
+  my ($self, @ips) = @_; # $ip arg for testing
 
-  $ip ||= $self->subnet;
-  my $pl    = $ip->prefixlen;
-  my $class = int( $pl / 8 );
-  my @quads = split /\./, $ip->ip;
-  my @keep  = splice @quads, 0, $class;
-  my $fixed = join q{.}, @keep;
-  my $bits  = 8 - ($pl - $class * 8);
+  @ips = $self->subnets unless @ips;
 
-  return $fixed if $bits == 8;
+  my @prefixes;
+
+  for my $ip (@ips) {
+    my $pl    = $ip->prefixlen;
+    my $class = int( $pl / 8 );
+    my @quads = split /\./, $ip->ip;
+    my @keep  = splice @quads, 0, $class;
+    my $fixed = join q{.}, @keep;
+    my $bits  = 8 - ($pl - $class * 8);
+
+    if ($bits == 8) {
+      push @prefixes, $fixed;
+    } else {
+      push @prefixes, map {; "$fixed.$_" } (0 .. (2**$bits - 1));
+    }
+  }
 
-  my @prefixes = map {; "$fixed.$_" } (0 .. (2**$bits - 1));
   return @prefixes;
 }
 
@@ -88,7 +105,7 @@ DNS::Oterica::Network - a network to which results are served
 
 =head1 VERSION
 
-version 0.205
+version 0.206
 
 =head1 OVERVIEW
 
@@ -103,9 +120,9 @@ Like other DNS::Oterica objects, they should be created through the hub.
 
 This is the network's unique name.
 
-=head2 subnet
+=head2 subnets
 
-This is the C<Net::IP> range for the network at this network.
+This is the C<Net::IP> ranges for the network at this network.
 
 =head1 AUTHOR
 
@@ -113,7 +130,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
