@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package DNS::Oterica::RecordMaker::TinyDNS;
 # ABSTRACT: a tinydns recordmaker for DNSO.
-$DNS::Oterica::RecordMaker::TinyDNS::VERSION = '0.205';
+$DNS::Oterica::RecordMaker::TinyDNS::VERSION = '0.206';
 #pod =head1 DESCRIPTION
 #pod
 #pod This role provides logic for generating lines for the F<tinydns-data> program
@@ -105,22 +105,24 @@ sub a_and_ptr {
 sub ptr {
   my ($self, $rec) = @_;
 
-    my @lines;
-    for my $if ($self->__ip_locode_pairs($rec)) {
-      my $ip = $if->[0];
-      my @bytes = reverse split /\./, $ip;
+  my @lines;
+  for my $if ($self->__ip_locode_pairs($rec)) {
+    my $ip = $if->[0];
+    my @bytes = reverse split /\./, $ip;
 
-      splice @bytes, 1, 1, '0-24', $bytes[1] unless $bytes[-1] eq '10';
+    splice @bytes, 1, 1, '0-24', $bytes[1]
+      if $bytes[1] eq 237 && $bytes[2] eq 72 && $bytes[3] eq 208;
 
-      my $extended_arpa = join '.', @bytes, 'in-addr', 'arpa';
-      push @lines, sprintf "^%s:%s:%s:%s:%s\n",
-        $extended_arpa,
-        $rec->{name},
-        $rec->{ttl} || $self->_default_ttl,
-        $self->_serial_number,
-        $if->[1] eq 'FB' ? '' : $if->[1];
-    }
-    return @lines;
+    my $extended_arpa = join '.', @bytes, 'in-addr', 'arpa';
+    push @lines, sprintf "^%s:%s:%s:%s:%s\n",
+      $extended_arpa,
+      $rec->{name},
+      $rec->{ttl} || $self->_default_ttl,
+      $self->_serial_number,
+      $if->[1] eq 'FB' ? '' : $if->[1];
+  }
+
+  return @lines;
 }
 
 # TODO find out why we generate Z and & records for our IPs and refactor this
@@ -262,7 +264,7 @@ sub txt {
   # 'fqdn:s:ttl:timestamp:lo
   push @lines, sprintf qq{'%s:%s:%s:%s:%s\n},
     $name,
-    $rec->{text},
+    _colon_safe($rec->{text}),
     $rec->{ttl} || $self->_default_ttl,
     $self->_serial_number,
     '',
@@ -271,6 +273,12 @@ sub txt {
   return @lines;
 }
 
+sub _colon_safe {
+  my $str = $_[0];
+  $str =~ s/([^A-Za-z0-9=])/sprintf '\\%03o', ord $1/ge;
+  $str;
+}
+
 sub _escaped_octals {
   join q{}, map {; sprintf '\\%03o', ord } split //, pack 'n', $_[0];
 }
@@ -299,7 +307,7 @@ sub _hostname_to_labels {
 #pod   });
 #pod
 #pod This returns lines for SRV records following RFC 2782.  It takes the following
-#pod arguments:
+#pod special arguments:
 #pod
 #pod   domain    - the domain offering service
 #pod   service   - the well-known service name (http, imaps, finger)
@@ -342,6 +350,42 @@ sub srv {
   return @lines;
 }
 
+#pod =method dkim
+#pod
+#pod This returns lines for TXT records for DKIM keys.  It takes the following
+#pod arguments:
+#pod
+#pod   domain   - the domain
+#pod   selector - the key selector
+#pod
+#pod   ttl      - record time to live
+#pod
+#pod   tags     - the DKIM record tags, a hashref
+#pod
+#pod Any tag given in the hashref will be included.  C<p> is required.
+#pod
+#pod =cut
+
+sub dkim {
+  my ($self, $rec) = @_;
+
+  Carp::confess("no domain for DKIM record")     unless $rec->{domain};
+  Carp::confess("no selector for DKIM record")   unless $rec->{selector};
+  Carp::confess("no public key for DKIM record") unless $rec->{tags}{p};
+
+  my $tags = $rec->{tags};
+  my $name = "$rec->{selector}._domainkey.$rec->{domain}";
+  my $text = join q{; }, map {; "$_=$tags->{$_}" } sort keys %$tags;
+
+  # We can't use ->txt because tinydns will split TXT records (generated by ')
+  # up into 127b chunks.  DKIM doesn't let you do that. -- rjbs, 2016-10-04
+  return sprintf ':%s:16:\\%03o%s:%s',
+    $name,
+    length($text),
+    _colon_safe($text),
+    $rec->{ttl} || $self->_default_ttl;
+}
+
 1;
 
 __END__
@@ -356,7 +400,7 @@ DNS::Oterica::RecordMaker::TinyDNS - a tinydns recordmaker for DNSO.
 
 =head1 VERSION
 
-version 0.205
+version 0.206
 
 =head1 DESCRIPTION
 
@@ -399,7 +443,7 @@ Generate an C<^> line, for the reverse DNS of an IP address.
   });
 
 This returns lines for SRV records following RFC 2782.  It takes the following
-arguments:
+special arguments:
 
   domain    - the domain offering service
   service   - the well-known service name (http, imaps, finger)
@@ -411,13 +455,27 @@ arguments:
   priority  - numeric priority; lower numbers should be used first
   weight    - weight to break priority ties; higher numbers preferred
 
+=head2 dkim
+
+This returns lines for TXT records for DKIM keys.  It takes the following
+arguments:
+
+  domain   - the domain
+  selector - the key selector
+
+  ttl      - record time to live
+
+  tags     - the DKIM record tags, a hashref
+
+Any tag given in the hashref will be included.  C<p> is required.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
